//
//  Directory.swift
//  Directory
//
//  Created by Joe Gregg on 9/16/22.
//

import UIKit

class Directory {
    private var people : [Person]
    var user : DirectoryUser
    
    let archiveURL: URL = {
        let documentsDirectories =
            FileManager.default.urls(for: .documentDirectory, in: .userDomainMask)
        let documentDirectory = documentsDirectories.first!
        return documentDirectory.appendingPathComponent("user.plist")
    }()
    
    init() {
        do {
            let data = try Data(contentsOf: archiveURL)
            let unarchiver = PropertyListDecoder()
            user = try unarchiver.decode(DirectoryUser.self, from: data)
        } catch {
            user = DirectoryUser()
        }
        people = []
    }

    func getCount() -> Int {
        return people.count
    }
    
    func getPerson(at n : Int) -> Person {
        return people[n]
    }

    func saveUser() {
        do {
            let encoder = PropertyListEncoder()
            let data = try encoder.encode(user)
            try data.write(to: archiveURL)
        } catch {
        }
    }

    func newUser(success callback : @escaping () -> Void,failure complain : @escaping () -> Void) {
        let jsonData = try? JSONEncoder().encode(user)
        let urlStr = "https://cmsc106.net/directory/users"
        let url = URL(string: urlStr)
        var request = URLRequest(url: url!)
        request.httpMethod = "POST"
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        request.httpBody = jsonData
        let task = URLSession.shared.dataTask(with: request) { data, response, error in
            guard error == nil,(response as! HTTPURLResponse).statusCode == 200 else {
                DispatchQueue.main.async {
                        complain()
                    }
                return
            }
            self.user.key = try! JSONDecoder().decode(String.self, from: data!)
            DispatchQueue.main.async {
                self.saveUser()
            }
            self.people = []
            DispatchQueue.main.async {
                    callback()
                }
        }
        task.resume()
    }
    
    func getKey(success callback : @escaping () -> Void,failure complain : @escaping () -> Void) {
        if !user.name.isEmpty, !user.password.isEmpty {
            let urlStr = "https://cmsc106.net/directory/users?user=\(user.name)&password=\(user.password)"
            let url = URL(string: urlStr)
            let task = URLSession.shared.dataTask(with: url!) { data, response, error in
                guard error == nil,(response as! HTTPURLResponse).statusCode == 200 else {
                    DispatchQueue.main.async {
                            complain()
                        }
                    return
                }
                self.user.key = try! JSONDecoder().decode(String.self, from: data!)
                DispatchQueue.main.async {
                    self.saveUser()
                }
                self.refresh(callback)
            }
            task.resume()
        }
    }
    
    func refresh(_ callback : @escaping () -> Void) {
        if !user.key.isEmpty {
            let urlStr = "https://cmsc106.net/directory/people/" + user.key
            let url = URL(string: urlStr)
            let task = URLSession.shared.dataTask(with: url!) { data, response, error in
                if error == nil {
                self.people = try! JSONDecoder().decode([Person].self, from: data!)
                DispatchQueue.main.async {
                        callback()
                    }
                }
            }
            task.resume()
        }
    }
    
    func addPerson(_ p : Person,_ callback : @escaping () -> Void) {
        let jsonData = try? JSONEncoder().encode(p)
        let urlStr = "https://cmsc106.net/directory/people/\(user.key)"
        let url = URL(string: urlStr)
        var request = URLRequest(url: url!)
        request.httpMethod = "POST"
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        request.httpBody = jsonData
        let task = URLSession.shared.dataTask(with: request) { data, response, error in
            guard error == nil else {
                return
            }
            self.refresh(callback)
        }
        task.resume()
    }

    func removePerson(at n : Int,_ callback : @escaping () -> Void) {
        let toRemove = people[n]
        let urlStr = "https://cmsc106.net/directory/people/\(user.key)/\(toRemove.id)"
        let url = URL(string: urlStr)
        var request = URLRequest(url: url!)
        request.httpMethod = "DELETE"
        let task = URLSession.shared.dataTask(with: request) { data, response, error in
            guard error == nil else {
                return
            }
            self.refresh(callback)
        }
        task.resume()
    }

}
