//
//  LoginController.swift
//  Directory
//
//  Created by Joe Gregg on 9/26/22.
//

import UIKit

class LoginController: UIViewController {
    var directory : Directory = Directory()
    @IBOutlet var user : UITextField!
    @IBOutlet var password : UITextField!
    
    @IBAction func newUser(_ source : UIButton) {
        directory.user.name = user.text!
        directory.user.password = password.text!
        directory.newUser(success: {self.goToMain()},failure: {self.showAlert(message: "Add new user failed")})
    }
    
    @IBAction func login(_ source : UIButton) {
        if let name = user!.text, let pwd = password!.text {
            guard !name.isEmpty else {
                showAlert(message: "You must provide a user name")
                return
            }
            guard !pwd.isEmpty else {
                showAlert(message: "You must provide a password")
                return
            }
            directory.user.name = name
            directory.user.password = pwd
            directory.getKey(success:{self.goToMain()},failure:{self.showAlert(message: "Login failed")})
        }
    }
    
    func goToMain() {
        let storyBoard: UIStoryboard = UIStoryboard(name: "Main", bundle: nil)
        let mainViewController = storyBoard.instantiateViewController(withIdentifier: "Directory") as! UINavigationController
        let listView = mainViewController.viewControllers.first as! ViewController
        listView.directory = directory
        mainViewController.modalPresentationStyle = .fullScreen
        self.present(mainViewController, animated: true, completion: nil)
    }
    
    func showAlert(message msg : String) {
        let alert = UIAlertController(title:nil,message: msg,preferredStyle: .alert)
        let ok = UIAlertAction(title:"OK",style:.default) { action in }
        alert.addAction(ok)
        self.present(alert,animated: true,completion: nil)
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        if !directory.user.key.isEmpty {
            directory.refresh {
                self.goToMain()
            }
        }
    }
}
