//
//  ViewController.swift
//  Directory
//
//  Created by Joe Gregg on 9/16/22.
//

import UIKit

class ViewController: UITableViewController {
    var directory : Directory!
    var currentPerson : Person?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        currentPerson = nil
        // Do any additional setup after loading the view.
    }

    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return directory.getCount()
    }

    override func tableView(_ tableView: UITableView,
            cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        // Get a new or recycled cell
        let cell = UITableViewCell(style: .value1, reuseIdentifier: "UITableViewCell")
        
        let person = directory.getPerson(at:indexPath.row)

        cell.textLabel?.text = person.name
        cell.detailTextLabel?.text = person.office

        return cell
    }

    override func tableView(_ tableView: UITableView,
                            commit editingStyle: UITableViewCell.EditingStyle,
                            forRowAt indexPath: IndexPath) {
        // If the table view is asking to commit a delete command...
        if editingStyle == .delete {
            // Remove the item from the directory
            directory.removePerson(at: indexPath.row) {
                tableView.reloadData()
            }
        }
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        switch segue.identifier {
        case "AddPerson":
            let controller = segue.destination as! PersonController
            currentPerson = Person(name:"",office:"")
            controller.person = currentPerson
        default:
            preconditionFailure("Unexpected segue identifier")
        }
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        if let p = currentPerson {
            directory.addPerson(p) {
                self.tableView.reloadData()
                self.currentPerson = nil
            }
        }
    }
    
    @IBAction func logOut(_ button : UIButton) {
        directory.user.name = ""
        directory.user.password = ""
        directory.user.key = ""
        directory.saveUser()
        let storyBoard: UIStoryboard = UIStoryboard(name: "Main", bundle: nil)
        let loginController = storyBoard.instantiateViewController(withIdentifier: "LogIn")
        loginController.modalPresentationStyle = .fullScreen
        self.present(loginController, animated: true, completion: nil)
    }
}

